<?php $TRANSLATIONS = array(
"Save" => "Zapisz",
"Search" => "Szukaj",
"Close" => "Zamknij",
"Next" => "Następny",
"Clear" => "Wyczyść",
"Saving..." => "Zapisywanie...",
"Failed to save file" => "Błąd zapisu pliku",
"An error occurred!" => "Wystąpił błąd!",
"There are unsaved changes in the text editor" => "Są niezapisane zmiany w edytorze tekstu",
"There were unsaved changes, click here to go back" => "Są niezapisane zmiany, kliknij żeby wrócić"
);
